import 'package:flutter/material.dart';

// ignore: depend_on_referenced_packages
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class ColorsExample extends StatelessWidget {
  const ColorsExample({Key? key}) : super(key: key);

  Widget _buildColors(List<Color> colors) {
    return SingleChildScrollView(
      scrollDirection: Axis.horizontal,
      child: Row(
        children: colors
            .asMap()
            .map((i, color) => MapEntry(
                i,
                Container(
                  color: color,
                  height: 80.0,
                  width: 80.0,
                )))
            .values
            .toList(),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Colors',
      child: Padding(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        child: SingleChildScrollView(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Panel(
                title: 'Primary color',
                child: _buildColors([
                  SeniorColors.primaryColor100,
                  SeniorColors.primaryColor200,
                  SeniorColors.primaryColor300,
                  SeniorColors.primaryColor400,
                  SeniorColors.primaryColor500,
                  SeniorColors.primaryColor600,
                  SeniorColors.primaryColor700,
                  SeniorColors.primaryColor800,
                  SeniorColors.primaryColor900,
                ]),
              ),
              Panel(
                title: 'Secondary color',
                child: _buildColors([
                  SeniorColors.secondaryColor100,
                  SeniorColors.secondaryColor200,
                  SeniorColors.secondaryColor300,
                  SeniorColors.secondaryColor400,
                  SeniorColors.secondaryColor500,
                  SeniorColors.secondaryColor600,
                  SeniorColors.secondaryColor700,
                  SeniorColors.secondaryColor800,
                  SeniorColors.secondaryColor900,
                ]),
              ),
              Panel(
                title: 'Neutral color',
                child: _buildColors([
                  SeniorColors.neutralColor100,
                  SeniorColors.neutralColor200,
                  SeniorColors.neutralColor300,
                  SeniorColors.neutralColor400,
                  SeniorColors.neutralColor500,
                  SeniorColors.neutralColor600,
                  SeniorColors.neutralColor700,
                  SeniorColors.neutralColor800,
                  SeniorColors.neutralColor900,
                ]),
              ),
              Panel(
                title: 'Grayscale',
                child: _buildColors([
                  SeniorColors.grayscale0,
                  SeniorColors.grayscale5,
                  SeniorColors.grayscale10,
                  SeniorColors.grayscale20,
                  SeniorColors.grayscale30,
                  SeniorColors.grayscale40,
                  SeniorColors.grayscale50,
                  SeniorColors.grayscale60,
                  SeniorColors.grayscale70,
                  SeniorColors.grayscale80,
                  SeniorColors.grayscale90,
                  SeniorColors.grayscale100,
                ]),
              ),
              Panel(
                title: 'Supporting color',
                child: _buildColors([
                  SeniorColors.supportingColor100,
                  SeniorColors.supportingColor200,
                  SeniorColors.supportingColor300,
                  SeniorColors.supportingColor400,
                  SeniorColors.supportingColor500,
                  SeniorColors.supportingColor600,
                  SeniorColors.supportingColor700,
                  SeniorColors.supportingColor800,
                  SeniorColors.supportingColor900,
                ]),
              ),
              Panel(
                title: 'Manchester red color',
                child: _buildColors([
                  SeniorColors.manchesterColorRed100,
                  SeniorColors.manchesterColorRed200,
                  SeniorColors.manchesterColorRed300,
                  SeniorColors.manchesterColorRed400,
                  SeniorColors.manchesterColorRed500,
                  SeniorColors.manchesterColorRed600,
                  SeniorColors.manchesterColorRed700,
                  SeniorColors.manchesterColorRed800,
                  SeniorColors.manchesterColorRed900,
                ]),
              ),
              Panel(
                title: 'Manchester orange color',
                child: _buildColors([
                  SeniorColors.manchesterColorOrange100,
                  SeniorColors.manchesterColorOrange200,
                  SeniorColors.manchesterColorOrange300,
                  SeniorColors.manchesterColorOrange400,
                  SeniorColors.manchesterColorOrange500,
                  SeniorColors.manchesterColorOrange600,
                  SeniorColors.manchesterColorOrange700,
                  SeniorColors.manchesterColorOrange800,
                  SeniorColors.manchesterColorOrange900,
                ]),
              ),
              Panel(
                title: 'Manchester yellow color',
                child: _buildColors([
                  SeniorColors.manchesterColorYellow100,
                  SeniorColors.manchesterColorYellow200,
                  SeniorColors.manchesterColorYellow300,
                  SeniorColors.manchesterColorYellow400,
                  SeniorColors.manchesterColorYellow500,
                  SeniorColors.manchesterColorYellow600,
                  SeniorColors.manchesterColorYellow700,
                  SeniorColors.manchesterColorYellow800,
                  SeniorColors.manchesterColorYellow900,
                ]),
              ),
              Panel(
                title: 'Manchester green color',
                child: _buildColors([
                  SeniorColors.manchesterColorGreen100,
                  SeniorColors.manchesterColorGreen200,
                  SeniorColors.manchesterColorGreen300,
                  SeniorColors.manchesterColorGreen400,
                  SeniorColors.manchesterColorGreen500,
                  SeniorColors.manchesterColorGreen600,
                  SeniorColors.manchesterColorGreen700,
                  SeniorColors.manchesterColorGreen800,
                  SeniorColors.manchesterColorGreen900,
                ]),
              ),
              Panel(
                title: 'Manchester blue color',
                child: _buildColors([
                  SeniorColors.manchesterColorBlue100,
                  SeniorColors.manchesterColorBlue200,
                  SeniorColors.manchesterColorBlue300,
                  SeniorColors.manchesterColorBlue400,
                  SeniorColors.manchesterColorBlue500,
                  SeniorColors.manchesterColorBlue600,
                  SeniorColors.manchesterColorBlue700,
                  SeniorColors.manchesterColorBlue800,
                  SeniorColors.manchesterColorBlue900,
                ]),
              ),
              Panel(
                title: 'Pure white',
                child: _buildColors([
                  SeniorColors.pureWhite,
                ]),
              ),
              Panel(
                title: 'Pure black',
                child: _buildColors([
                  SeniorColors.pureBlack,
                ]),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
